@@ -37,11 +37,11 @@ def init_subcommand(
     """
     Setups basic challenge files
     """
-    from aicrowd.challenge import init
+    from aicrowd.challenge import init_challenge
     from aicrowd.challenge.exceptions import ChallengeException
 
     try:
-        init(challenge, base_dir, mkdir, config_ctx)
+        init_challenge(challenge, base_dir, mkdir, config_ctx)
     except ChallengeException as e:
         click.echo(click.style(e.message, fg="red"))
         if e.fix:
