@@ -15,8 +15,12 @@ from aicrowd.utils.jupyter import is_google_colab_env, mount_google_drive
 
 
 def read_notebook(file_path: str) -> Dict[str, Any]:
-    with open(file_path) as fp:
-        nb = json.load(fp)
+    try:
+        with open(file_path) as fp:
+            nb = json.load(fp)
+    except UnicodeDecodeError:
+        with open(file_path, encoding="utf-8") as fp:
+            nb = json.load(fp)
     return nb
 
 
@@ -100,7 +104,7 @@ def get_notebook_path():
 
 
 def get_jupyter_notebook_path():
-    return os.path.join(os.getcwd(), get_latest_jupyter_session()["name"])
+    return os.path.join(os.getcwd(), get_latest_jupyter_session()["path"])
 
 
 def get_colab_notebook_path():
@@ -108,7 +112,7 @@ def get_colab_notebook_path():
     return os.path.join(
         mount_path,
         "MyDrive/Colab Notebooks",
-        unquote(get_latest_jupyter_session()["name"]),
+        unquote(get_latest_jupyter_session()["path"]),
     )
 
 
